@@ -1,5 +1,5 @@
 /*************************************************************************
-* ph0llux:f8d89970ef41b3cc94a19be386c2fde11f8653d2a085dd0d6bd7fbf2d99f42e3
+* ph0llux:8bdfff90b1391c04afb20ca2f246d5af5fef34f7d8688b39c3a36f9a85717d0f
 *************************************************************************/
 //! stdext module
 // - STD
@@ -8,16 +8,20 @@ use std::num::ParseIntError;
  
 // - internal
 use crate as phollaits;
+use crate::{PhollaitsError, Result};
 
 /// Trait contains some extensions for [bool].
 pub trait BoolExtensions {
 	/// method to reverse the value of a bool.
 	/// # Example
 	/// ```rust
+	/// extern crate phollaits;
+	/// use phollaits::{BoolExtensions};
+	///
 	/// fn main() {
-	/// 	let a = true;
+	/// 	let mut a = true;
 	/// 	a.reverse();
-	/// 	asserteq!(a, false);
+	/// 	assert_eq!(a, false);
 	/// }
 	/// ```
 	fn reverse(&mut self);
@@ -81,7 +85,7 @@ impl<T: ToString> OptionExtensions<T> for Option<T> {
 pub trait StringExt {
 	/// method to allow shell-like expansions in [String].
 	/// # Example to expand tilda
-	/// ```rust
+	/// ```no_run
 	/// extern crate phollaits;
 	/// use phollaits::*;
 	///
@@ -109,13 +113,13 @@ pub trait StringExt {
 
 	/// converts a 'hexified' String to a Vec of Bytes.
 	/// # Example
-	/// fn main() -> Result<(), ParseIntError> {
+	/// fn main() -> Result<(), PhollaitsError> {
 	/// 	let m = "6f5902ac237024bdd0c176cb93063dc4".to_string();
 	/// 	let m_as_bytes = m.hex_to_bytes()?;
 	/// 	assert_eq!(m_as_bytes, [111, 89, 2, 172, 35, 112, 36, 189, 208, 193, 118, 203, 147, 6, 61, 196]);
 	/// 	Ok(())
 	/// }
-	fn hex_to_bytes(self) -> Result<Vec<u8>, ParseIntError>;
+	fn hex_to_bytes(self) -> Result<Vec<u8>>;
 }
 
 impl StringExt for String {
@@ -146,17 +150,23 @@ impl StringExt for String {
 	    String::from(trimmed_string)
 	}
 
-	fn hex_to_bytes(self) -> Result<Vec<u8>, ParseIntError> {
-		fn inner_hex_to_bytes(s: &str) -> Result<u8, ParseIntError> {
+	fn hex_to_bytes(self) -> Result<Vec<u8>> {
+		fn inner_hex_to_bytes(s: &str) -> std::result::Result<u8, ParseIntError> {
 		    u8::from_str_radix(s, 16).map(|n| n as u8)
 		}
+		fn get_vec(chunks: Vec<String>) -> std::result::Result<Vec<u8>, ParseIntError> {
+	    	chunks.into_iter().map(|x| inner_hex_to_bytes(&x)).collect()
+	    }
 	    let mut chunks = Vec::new();
 	    let mut z = self.chars().peekable();
 	    while z.peek().is_some() {
 	    	let chunk: String = z.by_ref().take(2).collect();
 	    	chunks.push(chunk)
 	    }
-	    chunks.into_iter().map(|x| inner_hex_to_bytes(&x)).collect()
+	    match get_vec(chunks) {
+	    	Ok(x) => Ok(x),
+	    	Err(e) => Err(PhollaitsError::from(e))
+	    }
 	}
 }
 
@@ -187,18 +197,23 @@ impl StringExt for &str {
 		}
 	    String::from(trimmed_string)
 	}
-
-	fn hex_to_bytes(self) -> Result<Vec<u8>, ParseIntError> {
-		fn inner_hex_to_bytes(s: &str) -> Result<u8, ParseIntError> {
+	fn hex_to_bytes(self) -> Result<Vec<u8>> {
+		fn inner_hex_to_bytes(s: &str) -> std::result::Result<u8, ParseIntError> {
 		    u8::from_str_radix(s, 16).map(|n| n as u8)
 		}
+		fn get_vec(chunks: Vec<String>) -> std::result::Result<Vec<u8>, ParseIntError> {
+	    	chunks.into_iter().map(|x| inner_hex_to_bytes(&x)).collect()
+	    }
 	    let mut chunks = Vec::new();
 	    let mut z = self.chars().peekable();
 	    while z.peek().is_some() {
 	    	let chunk: String = z.by_ref().take(2).collect();
 	    	chunks.push(chunk)
 	    }
-	    chunks.into_iter().map(|x| inner_hex_to_bytes(&x)).collect()
+	    match get_vec(chunks) {
+	    	Ok(x) => Ok(x),
+	    	Err(e) => Err(PhollaitsError::from(e))
+	    }
 	}
 }
 
@@ -215,12 +230,12 @@ impl VecExt for Vec<&str> {
 	/// extern crate phollaits;
 	/// use phollaits::*;
 	/// 
-	///	const a: [&'static str; 6] = [ "a", "b", "c" ];
+	///	const a: [&'static str; 3] = [ "a", "b", "c" ];
 	///
 	/// fn main() {
-	/// 	let b = a.to_vec;
+	/// 	let b = a.to_vec();
 	///		let c = vec!("a".to_string(), "b".to_string(), "c".to_string());
-	/// 	assert_eq!(b.to_vec_string, c);
+	/// 	assert_eq!(b.to_vec_string(), c);
 	/// }
 	/// ```
 	fn to_vec_string(self) -> Vec<String> {
